import json
import os
import sys


config = {}

def init():
    """Initialize config from file and env vars"""
    global config
    
	# Read config from file
    # Config in `config.json` may be overwritten by environment variables, see later in this function
    config_file = "config.json"
    try:
        with open(config_file, 'r', encoding='utf-8') as file:
            config = json.load(file)  # Read and convert JSON to dict
    except FileNotFoundError:
        print("No config was provided at ./config.json. Make sure to provide necessary configs as env vars.", file=sys.stderr)
    except json.JSONDecodeError:
        raise Exception("Config file at ./config.json is not valid JSON and could not be decoded.")
    except PermissionError:
        raise Exception("No permission to open config file at ./config.json")
    except Exception as e:
        raise Exception(f"Could not read config: {e}")
    
	# Read config from env vars
    # This reads all env vars that begin with the prefix `SFPHOTON_WEB_` and adds them to the config (stripped from the prefix)
    # Env vars will overwrite config from file
    config.update({key[13:]: value for key, value in os.environ.items() if key.startswith("SFPHOTON_WEB_")})
        
def get(key: str):
    if key in config:
        return config[key]
    else:
        return None